@@ -1,5 +1,3 @@
-from __future__ import annotations
-
 import asyncio
 import os
 import sys
@@ -8,16 +6,13 @@ import typing as t
 from contextvars import ContextVar
 from datetime import datetime
 from enum import Enum
-from functools import cache
+from functools import lru_cache
 from importlib import import_module, util
 from inspect import stack
 from pathlib import Path
 from uuid import UUID
 
-try:
-    import nest_asyncio
-except ImportError:
-    nest_asyncio = None
+# Removed nest_asyncio import - not needed in library code
 import rich.repr
 from anyio import Path as AsyncPath
 from inflection import camelize
@@ -26,14 +21,21 @@ from pydantic import BaseModel, ConfigDict, Field
 from acb.actions.encode import yaml_encode
 from acb.depends import depends
 
+# Declare uuid_utils to handle both import cases
+uuid_utils: t.Any = None  # Initialize as None
+
 try:
-    import uuid_utils as uuid_lib
+    import uuid_utils  # type: ignore[no-redef]
 
     _uuid7_available = True
+    uuid_lib: t.Any = uuid_utils  # type: ignore[no-redef]
 except ImportError:
-    import uuid as uuid_lib
+    import uuid
+
+    uuid_utils = None  # type: ignore[no-redef]
 
     _uuid7_available = False
+    uuid_lib: t.Any = uuid  # type: ignore[no-redef]
 
 
 class AdapterStatus(str, Enum):
@@ -48,6 +50,7 @@ class AdapterCapability(str, Enum):
     CONNECTION_POOLING = "connection_pooling"
     RECONNECTION = "auto_reconnection"
     HEALTH_CHECKS = "health_checks"
+    TLS_SUPPORT = "tls_support"
 
     TRANSACTIONS = "transactions"
     BULK_OPERATIONS = "bulk_operations"
@@ -67,10 +70,56 @@ class AdapterCapability(str, Enum):
     MIGRATIONS = "migrations"
     BACKUP_RESTORE = "backup_restore"
 
+    # Logger-specific capabilities
+    STRUCTURED_OUTPUT = "structured_output"
+    ASYNC_LOGGING = "async_logging"
+    CONTEXTUAL = "contextual"
+    ROTATION = "rotation"
+    REMOTE_LOGGING = "remote_logging"
+    JSON_OUTPUT = "json_output"
+    FILE_LOGGING = "file_logging"
+    CORRELATION_ID = "correlation_id"
+
+    # Graph-specific capabilities
+    GRAPH_TRAVERSAL = "graph_traversal"
+    CYPHER_QUERIES = "cypher_queries"
+    GREMLIN_QUERIES = "gremlin_queries"
+    AQL_QUERIES = "aql_queries"
+    GRAPH_ANALYTICS = "graph_analytics"
+    PATHFINDING = "pathfinding"
+    SUBGRAPH_OPERATIONS = "subgraph_operations"
+    GRAPH_SCHEMA_VALIDATION = "graph_schema_validation"
+
+    # AI/ML-specific capabilities
+    HYBRID_DEPLOYMENT = "hybrid_deployment"
+    EDGE_INFERENCE = "edge_inference"
+    MULTIMODAL_PROCESSING = "multimodal_processing"
+    PROMPT_TEMPLATING = "prompt_templating"
+    MODEL_CACHING = "model_caching"
+    ADAPTIVE_ROUTING = "adaptive_routing"
+    FALLBACK_MECHANISMS = "fallback_mechanisms"
+    TEXT_GENERATION = "text_generation"
+    VISION_PROCESSING = "vision_processing"
+    AUDIO_PROCESSING = "audio_processing"
+    MODEL_QUANTIZATION = "model_quantization"
+    COLD_START_OPTIMIZATION = "cold_start_optimization"
+
+    # Embedding-specific capabilities
+    BATCH_EMBEDDING = "batch_embedding"
+    EDGE_OPTIMIZED = "edge_optimized"
+    TEXT_PREPROCESSING = "text_preprocessing"
+    VECTOR_NORMALIZATION = "vector_normalization"
+    DIMENSION_SCALING = "dimension_scaling"
+    SEMANTIC_SEARCH = "semantic_search"
+    SIMILARITY_COMPUTATION = "similarity_computation"
+    DOCUMENT_CHUNKING = "document_chunking"
+    POOLING_STRATEGIES = "pooling_strategies"
+    MEMORY_EFFICIENT_PROCESSING = "memory_efficient_processing"
+
 
 class AdapterMetadata(BaseModel):
     module_id: UUID = Field(
-        description="UUID7 identifier for this specific adapter module"
+        description="UUID7 identifier for this specific adapter module",
     )
 
     name: str = Field(description="Human-readable adapter name")
@@ -78,11 +127,12 @@ class AdapterMetadata(BaseModel):
     provider: str = Field(description="Technology provider (redis, mysql, s3, etc.)")
 
     version: str = Field(
-        description="Semantic version of this adapter (independent of ACB version)"
+        description="Semantic version of this adapter (independent of ACB version)",
     )
     acb_min_version: str = Field(description="Minimum ACB version required")
     acb_max_version: str | None = Field(
-        default=None, description="Maximum ACB version supported (None = no limit)"
+        default=None,
+        description="Maximum ACB version supported (None = no limit)",
     )
 
     author: str = Field(description="Primary author/maintainer")
@@ -91,27 +141,33 @@ class AdapterMetadata(BaseModel):
 
     status: AdapterStatus = Field(description="Development/stability status")
     capabilities: list[AdapterCapability] = Field(
-        default_factory=list, description="List of features this adapter supports"
+        default_factory=list,
+        description="List of features this adapter supports",
     )
 
     required_packages: list[str] = Field(
-        default_factory=list, description="External packages required for this adapter"
+        default_factory=list,
+        description="External packages required for this adapter",
     )
     optional_packages: dict[str, str] = Field(
-        default_factory=dict, description="Optional packages and their purpose"
+        default_factory=dict,
+        description="Optional packages and their purpose",
     )
 
     description: str = Field(description="Brief description of adapter functionality")
     documentation_url: str | None = Field(
-        default=None, description="Link to detailed documentation"
+        default=None,
+        description="Link to detailed documentation",
     )
     repository_url: str | None = Field(
-        default=None, description="Source code repository for this adapter"
+        default=None,
+        description="Source code repository for this adapter",
     )
 
     settings_class: str = Field(description="Name of the settings class")
     config_example: dict[str, t.Any] | None = Field(
-        default=None, description="Example configuration for this adapter"
+        default=None,
+        description="Example configuration for this adapter",
     )
 
     custom: dict[str, t.Any] = Field(
@@ -119,18 +175,20 @@ class AdapterMetadata(BaseModel):
         description="Custom metadata fields for specific requirements",
     )
 
-    class Config:
-        use_enum_values = True
-        extra = "forbid"
+    model_config = ConfigDict(use_enum_values=True, extra="forbid")
 
 
 def generate_adapter_id() -> UUID:
     if _uuid7_available:
         uuid_obj = uuid_lib.uuid7()  # type: ignore[attr-defined]
-        return UUID(str(uuid_obj)) if not isinstance(uuid_obj, UUID) else uuid_obj
-    else:
-        uuid_obj = uuid_lib.uuid4()
-        return UUID(str(uuid_obj)) if not isinstance(uuid_obj, UUID) else uuid_obj
+        return (
+            UUID(str(uuid_obj))
+            if not isinstance(uuid_obj, UUID)
+            else UUID(str(uuid_obj))
+        )
+    uuid_obj = uuid_lib.uuid4()
+    # Explicitly cast to UUID to satisfy type checker
+    return UUID(str(uuid_obj))
 
 
 def create_metadata_template(
@@ -161,7 +219,8 @@ def create_metadata_template(
 
 
 def validate_version_compatibility(
-    adapter_metadata: AdapterMetadata, current_acb_version: str
+    adapter_metadata: AdapterMetadata,
+    current_acb_version: str,
 ) -> bool:
     try:
         from packaging import version
@@ -187,7 +246,7 @@ def extract_metadata_from_module(module: t.Any) -> AdapterMetadata | None:
         metadata = module.MODULE_METADATA
         if isinstance(metadata, AdapterMetadata):
             return metadata
-        elif isinstance(metadata, dict):
+        if isinstance(metadata, dict):
             return AdapterMetadata(**metadata)
     return None
 
@@ -197,7 +256,7 @@ def extract_metadata_from_class(adapter_class: type) -> AdapterMetadata | None:
         metadata = adapter_class.__module_metadata__
         if isinstance(metadata, AdapterMetadata):
             return metadata
-        elif isinstance(metadata, dict):
+        if isinstance(metadata, dict):
             return AdapterMetadata(**metadata)
     return None
 
@@ -234,7 +293,8 @@ def get_adapter_info(adapter_class: type) -> dict[str, t.Any]:
 
 
 def check_adapter_capability(
-    adapter_class: type, capability: AdapterCapability
+    adapter_class: type,
+    capability: AdapterCapability,
 ) -> bool:
     metadata = extract_metadata_from_class(adapter_class)
     if metadata:
@@ -286,8 +346,7 @@ Class: {info["class_name"]}
 """.strip()
 
 
-if nest_asyncio:
-    nest_asyncio.apply()
+# Removed nest_asyncio.apply() - not needed in library code
 _deployed: bool = os.getenv("DEPLOYED", "False").lower() == "true"
 _testing: bool = os.getenv("TESTING", "False").lower() == "true"
 root_path: AsyncPath = AsyncPath(Path.cwd())
@@ -295,9 +354,9 @@ tmp_path: AsyncPath = root_path / "tmp"
 adapters_path: AsyncPath = root_path / "adapters"
 actions_path: AsyncPath = root_path / "actions"
 settings_path: AsyncPath = root_path / "settings"
-app_settings_path: AsyncPath = settings_path / "app.yml"
-debug_settings_path: AsyncPath = settings_path / "debug.yml"
-adapter_settings_path: AsyncPath = settings_path / "adapters.yml"
+app_settings_path: AsyncPath = settings_path / "app.yaml"
+debug_settings_path: AsyncPath = settings_path / "debug.yaml"
+adapter_settings_path: AsyncPath = settings_path / "adapters.yaml"
 secrets_path: AsyncPath = (
     AsyncPath(Path(tempfile.mkdtemp(prefix="mock_secrets_")))
     if _testing or "pytest" in sys.modules
@@ -316,8 +375,7 @@ class AdapterNotFound(Exception): ...
 class AdapterNotInstalled(Exception): ...
 
 
-class StaticImportError(ImportError):
-    pass
+class StaticImportError(ImportError): ...
 
 
 AdapterClass = t.TypeVar("AdapterClass")
@@ -353,7 +411,7 @@ class Adapter(BaseModel):
     def __hash__(self) -> int:
         base_hash = (self.name, self.class_name, self.category, self.pkg, self.module)
         if self.metadata:
-            return hash(base_hash + (str(self.metadata.module_id),))
+            return hash((*base_hash, str(self.metadata.module_id)))
         return hash(base_hash)
 
     def __eq__(self, other: object) -> bool:
@@ -389,12 +447,12 @@ core_adapters = [
     ),
     Adapter(
         name="loguru",
-        module="acb.logger",
+        module="acb.adapters.logger.loguru",
         class_name="Logger",
         category="logger",
         enabled=True,
         installed=True,
-        path=AsyncPath(__file__).parent / "logger.py",
+        path=AsyncPath(__file__).parent / "logger" / "loguru.py",
     ),
 ]
 
@@ -407,8 +465,8 @@ def _update_adapter_caches() -> None:
             enabled_cache[adapter.category] = adapter
         if adapter.installed:
             installed_cache[adapter.category] = adapter
-    _enabled_adapters_cache.set(enabled_cache)
-    _installed_adapters_cache.set(installed_cache)
+    _enabled_adapters_cache.get().update(enabled_cache)
+    _installed_adapters_cache.get().update(installed_cache)
 
 
 adapter_registry.get().extend([*core_adapters])
@@ -431,17 +489,113 @@ def get_installed_adapters() -> list[Adapter]:
     return list(_installed_adapters_cache.get().values())
 
 
-@cache
+# Static adapter mappings for improved performance
+# This eliminates the need for dynamic string construction and reduces import overhead
+STATIC_ADAPTER_MAPPINGS = {
+    "cache.memory": ("acb.adapters.cache.memory", "Cache"),
+    "cache.redis": ("acb.adapters.cache.redis", "Cache"),
+    "logger": ("acb.adapters.logger.loguru", "Logger"),  # Default logger (loguru)
+    "logger.loguru": ("acb.adapters.logger.loguru", "Logger"),
+    "logger.structlog": ("acb.adapters.logger.structlog", "Logger"),
+    "logger.logly": ("acb.adapters.logger.logly", "Logger"),
+    "sql.mysql": ("acb.adapters.sql.mysql", "Sql"),
+    "sql.pgsql": ("acb.adapters.sql.pgsql", "Sql"),
+    "sql.sqlite": ("acb.adapters.sql.sqlite", "Sql"),
+    "nosql.mongodb": ("acb.adapters.nosql.mongodb", "Nosql"),
+    "nosql.firestore": ("acb.adapters.nosql.firestore", "Nosql"),
+    "nosql.redis": ("acb.adapters.nosql.redis", "Nosql"),
+    "storage.file": ("acb.adapters.storage.file", "Storage"),
+    "storage.s3": ("acb.adapters.storage.s3", "Storage"),
+    "storage.azure": ("acb.adapters.storage.azure", "Storage"),
+    "storage.cloud_storage": ("acb.adapters.storage.cloud_storage", "Storage"),
+    "storage.memory": ("acb.adapters.storage.memory", "Storage"),
+    "secret.infisical": ("acb.adapters.secret.infisical", "Secret"),
+    "secret.secret_manager": ("acb.adapters.secret.secret_manager", "Secret"),
+    "secret.azure": ("acb.adapters.secret.azure", "Secret"),
+    "secret.cloudflare": ("acb.adapters.secret.cloudflare", "Secret"),
+    "monitoring.sentry": ("acb.adapters.monitoring.sentry", "Monitoring"),
+    "monitoring.logfire": ("acb.adapters.monitoring.logfire", "Monitoring"),
+    "requests.httpx": ("acb.adapters.requests.httpx", "Requests"),
+    "requests.niquests": ("acb.adapters.requests.niquests", "Requests"),
+    "smtp.gmail": ("acb.adapters.smtp.gmail", "Smtp"),
+    "smtp.mailgun": ("acb.adapters.smtp.mailgun", "Smtp"),
+    "dns.cloud_dns": ("acb.adapters.dns.cloud_dns", "Dns"),
+    "dns.cloudflare": ("acb.adapters.dns.cloudflare", "Dns"),
+    "dns.route53": ("acb.adapters.dns.route53", "Dns"),
+    "ftpd.ftp": ("acb.adapters.ftpd.ftp", "Ftpd"),
+    "ftpd.sftp": ("acb.adapters.ftpd.sftp", "Ftpd"),
+    "models": ("acb.adapters.models", "Models"),
+    "vector.duckdb": ("acb.adapters.vector.duckdb", "Vector"),
+    "vector.pinecone": ("acb.adapters.vector.pinecone", "Vector"),
+    "vector.qdrant": ("acb.adapters.vector.qdrant", "Vector"),
+    "vector.weaviate": ("acb.adapters.vector.weaviate", "Vector"),
+    "graph.neo4j": ("acb.adapters.graph.neo4j", "Graph"),
+    "graph.neptune": ("acb.adapters.graph.neptune", "Graph"),
+    "graph.arangodb": ("acb.adapters.graph.arangodb", "Graph"),
+    # Pub/Sub adapters for events system
+    "pubsub.memory": ("acb.adapters.messaging.memory", "MemoryPubSub"),
+    "pubsub.redis": ("acb.adapters.messaging.redis", "RedisPubSub"),
+    "pubsub.rabbitmq": ("acb.adapters.messaging.rabbitmq", "RabbitMQPubSub"),
+    "pubsub.aiormq": ("acb.adapters.messaging.aiormq", "AioRmqPubSub"),
+    # Queue adapters for tasks system
+    "queue.memory": ("acb.adapters.messaging.memory", "MemoryQueue"),
+    "queue.redis": ("acb.adapters.messaging.redis", "RedisQueue"),
+    "queue.rabbitmq": ("acb.adapters.messaging.rabbitmq", "RabbitMQQueue"),
+    "queue.aiormq": ("acb.adapters.messaging.aiormq", "AioRmqQueue"),
+    # Task system adapters
+    "tasks.memory": ("acb.tasks.memory", "TaskSystem"),
+    "tasks.redis": ("acb.tasks.redis", "TaskSystem"),
+    "tasks.rabbitmq": ("acb.tasks.rabbitmq", "TaskSystem"),
+    "tasks.apscheduler": ("acb.tasks.apscheduler", "TaskSystem"),
+    "ai.cloud": ("acb.adapters.ai.cloud", "CloudAI"),
+    "ai.edge": ("acb.adapters.ai.edge", "EdgeAI"),
+    "ai.hybrid": ("acb.adapters.ai.hybrid", "HybridAI"),
+    "embedding.openai": ("acb.adapters.embedding.openai", "Embedding"),
+    "embedding.huggingface": ("acb.adapters.embedding.huggingface", "Embedding"),
+    "embedding.sentence_transformers": (
+        "acb.adapters.embedding.sentence_transformers",
+        "Embedding",
+    ),
+    "embedding.onnx": ("acb.adapters.embedding.onnx", "Embedding"),
+    "embedding.lfm": ("acb.adapters.embedding.lfm", "Embedding"),
+    "reasoning.langchain": ("acb.adapters.reasoning.langchain", "Reasoning"),
+    "reasoning.llamaindex": ("acb.adapters.reasoning.llamaindex", "Reasoning"),
+    "reasoning.custom": ("acb.adapters.reasoning.custom", "Reasoning"),
+    "reasoning.openai_functions": (
+        "acb.adapters.reasoning.openai_functions",
+        "Reasoning",
+    ),
+    "type.zuban": ("acb.adapters.type.zuban", "ZubanAdapter"),
+}
+
+
+@lru_cache(maxsize=256)
 def get_adapter_class(category: str, name: str) -> type[t.Any]:
+    """Get adapter class with optimized static mappings and caching.
+
+    This function uses pre-computed static mappings for better performance
+    and falls back to dynamic import for custom adapters.
+    """
+    # Try static mapping first for maximum performance
+    mapping_key = f"{category}.{name}" if name != category else category
+    if mapping_key in STATIC_ADAPTER_MAPPINGS:
+        module_path, class_name = STATIC_ADAPTER_MAPPINGS[mapping_key]
+        return _import_adapter_class_cached(module_path, class_name)
+
+    # Fallback to dynamic import for custom adapters
     module_path = f"acb.adapters.{category}.{name}"
+    class_name = camelize(category)
+    return _import_adapter_class_cached(module_path, class_name)
+
+
+@lru_cache(maxsize=512)
+def _import_adapter_class_cached(module_path: str, class_name: str) -> type:
+    """Cached adapter class import to avoid repeated module loading."""
     try:
-        from importlib import import_module
-
-        from inflection import camelize
-
-        class_name = camelize(category)
         module = import_module(module_path)
         adapter_class = getattr(module, class_name)
+
+        # Attach metadata if available
         if hasattr(module, "MODULE_METADATA"):
             metadata = module.MODULE_METADATA
             if isinstance(metadata, AdapterMetadata):
@@ -449,9 +603,9 @@ def get_adapter_class(category: str, name: str) -> type[t.Any]:
             elif isinstance(metadata, dict):
                 adapter_class.__module_metadata__ = AdapterMetadata(**metadata)
 
-        return adapter_class
+        return adapter_class  # type: ignore[no-any-return]
     except (ImportError, AttributeError) as e:
-        msg = f"Failed to import {module_path}: {e}"
+        msg = f"Failed to import {module_path}.{class_name}: {e}"
         raise StaticImportError(msg)
 
 
@@ -515,7 +669,7 @@ async def _setup_adapter_configuration() -> None:
     if await _should_skip_project_setup(cwd_path):
         return
     cwd_settings_path = cwd_path / "settings"
-    cwd_adapter_settings_path = cwd_settings_path / "adapters.yml"
+    cwd_adapter_settings_path = cwd_settings_path / "adapters.yaml"
     await _create_adapter_settings_if_needed(
         cwd_settings_path,
         cwd_adapter_settings_path,
@@ -586,10 +740,10 @@ async def _load_enabled_adapters(
 
 
 async def _ensure_package_registration() -> None:
-    from acb import ensure_registration_async, pkg_registry
+    from acb import ensure_registration_async, get_context
 
     await ensure_registration_async()
-    for pkg in pkg_registry.get():
+    for pkg in get_context().pkg_registry.get():
         if not pkg.adapters:
             from contextlib import suppress
 
@@ -598,10 +752,10 @@ async def _ensure_package_registration() -> None:
 
 
 async def _collect_all_adapters() -> list[Adapter]:
-    from acb import pkg_registry
+    from acb import get_context
 
     all_adapters = list(adapter_registry.get())
-    for pkg in pkg_registry.get():
+    for pkg in get_context().pkg_registry.get():
         for adapter in pkg.adapters:
             if adapter not in all_adapters:
                 adapter_registry.get().append(adapter)
@@ -647,12 +801,12 @@ async def _find_adapter(adapter_category: str) -> Adapter:
                     adapter = get_adapter(adapter_category)
                     if adapter is not None:
                         return adapter
-        msg = f"{adapter_category} adapter not found – check adapters.yml and ensure package registration"
+        msg = f"{adapter_category} adapter not found – check adapters.yaml and ensure package registration"
         raise AdapterNotFound(
             msg,
         )
     except AttributeError:
-        msg = f"{adapter_category} adapter not found – check adapters.yml"
+        msg = f"{adapter_category} adapter not found – check adapters.yaml"
         raise AdapterNotFound(
             msg,
         )
@@ -662,7 +816,7 @@ async def _load_module(adapter: Adapter) -> t.Any:
     try:
         module = import_module(adapter.module)
     except ModuleNotFoundError:
-        spec = util.spec_from_file_location(adapter.path.stem, adapter.path)
+        spec = util.spec_from_file_location(adapter.path.stem, str(adapter.path))
         if spec is None:
             msg = f"Failed to create module spec for {adapter.module}"
             raise AdapterNotFound(msg)
@@ -690,16 +844,16 @@ async def _initialize_adapter(
     if adapter_settings is not None:
         from acb.config import Config
 
-        config = depends.get(Config)
+        config = await depends.get(Config)
         setattr(config, adapter_category, adapter_settings)
-    instance = depends.get(adapter_class)
+    instance = await depends.get(adapter_class)
     if hasattr(instance, "init"):
         init_result = instance.init()
         if hasattr(init_result, "__await__"):
             await init_result
     from acb.logger import Logger
 
-    logger = depends.get(Logger)
+    logger = await depends.get(Logger)
     logger.info(f"Adapter initialized: {adapter.class_name}")
     return adapter_class
 
@@ -751,7 +905,6 @@ def import_adapter(adapter_categories: str | list[str] | None = None) -> t.Any:
         adapter_class = try_import_adapter(adapter_categories, adapter_name)
         if adapter_class:
             return adapter_class
-
         return import_adapter_with_context([adapter_categories])
 
     return import_adapter_with_context(adapter_categories)
@@ -816,13 +969,29 @@ def import_adapter_with_context(
     normalized_categories = _normalize_adapter_categories(adapter_categories)
 
     try:
-        imported_adapters = asyncio.run(gather_imports(normalized_categories))
+        # Check if we're in an async context
+        import asyncio
+
+        try:
+            asyncio.get_running_loop()
+            # We're in an async context - this function shouldn't be called here
+            msg = (
+                f"import_adapter_with_context() cannot be called from async context. "
+                f"Use 'await gather_imports({normalized_categories})' directly."
+            )
+            raise RuntimeError(msg)
+        except RuntimeError as e:
+            if "no running event loop" in str(e):
+                # No event loop - we need to start one for adapter imports
+                # This should only happen in application initialization
+                imported_adapters = asyncio.run(gather_imports(normalized_categories))
+            else:
+                raise
     except Exception as e:
         msg = f"Failed to install adapters {normalized_categories}: {e}"
         raise AdapterNotInstalled(
             msg,
         )
-
     return (
         imported_adapters[0]
         if len(imported_adapters) == 1
@@ -872,16 +1041,16 @@ def extract_adapter_modules(modules: list[AsyncPath], adapter: str) -> list[Adap
 async def register_adapters(path: AsyncPath) -> list[Adapter]:
     if _testing or "pytest" in sys.modules:
         return []
-    adapters_path = path / "adapters"
-    if not await adapters_path.exists():
+    _adapters_path = path / "adapters"
+    if not (await _adapters_path.exists()):
         return []
-    pkg_adapters = await path_adapters(adapters_path)
-    adapters: list[Adapter] = []
+    pkg_adapters = await path_adapters(_adapters_path)
+    _adapters: list[Adapter] = []
     for adapter_name, modules in pkg_adapters.items():
         _modules = extract_adapter_modules(modules, adapter_name)
-        adapters.extend(_modules)
+        _adapters.extend(_modules)
     registry = adapter_registry.get()
-    for a in adapters:
+    for a in _adapters:
         module = ".".join(a.module.split(".")[-2:])
         remove = next(
             (_a for _a in registry if ".".join(_a.module.split(".")[-2:]) == module),
@@ -892,4 +1061,7 @@ async def register_adapters(path: AsyncPath) -> list[Adapter]:
         registry.append(a)
         _adapter_import_locks.get()[a.category] = asyncio.Lock()
     _update_adapter_caches()
-    return adapters
+    return _adapters
+
+
+adapters = asyncio.run(register_adapters(AsyncPath(__file__).parent.parent))
